==> libgtcpsocket-0.1.0.tar.gz: libgtcpsocket-0.1.0/libgtcpsocket/gtcp-socket-type-builtins.c <==

/* Generated data (by glib-mkenums) */

#include <glib-object.h>
#include <gtcp-socket-types.h>


/* enumerations from "gtcp-socket-types.h" */
GType
gtcp_lookup_status_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { GTCP_LOOKUP_IN_PROGRESS, "GTCP_LOOKUP_IN_PROGRESS", "in-progress" },
      { GTCP_LOOKUP_OK, "GTCP_LOOKUP_OK", "ok" },
      { GTCP_LOOKUP_ERROR_NOT_FOUND, "GTCP_LOOKUP_ERROR_NOT_FOUND", "error-not-found" },
      { GTCP_LOOKUP_ERROR_NO_RECOVERY, "GTCP_LOOKUP_ERROR_NO_RECOVERY", "error-no-recovery" },
      { GTCP_LOOKUP_ERROR_TRY_AGAIN, "GTCP_LOOKUP_ERROR_TRY_AGAIN", "error-try-again" },
      { GTCP_LOOKUP_ERROR_IPV4_IPV6_MISMATCH, "GTCP_LOOKUP_ERROR_IPV4_IPV6_MISMATCH", "error-ipv4-ipv6-mismatch" },
      { GTCP_LOOKUP_ERROR_THREAD_ERROR, "GTCP_LOOKUP_ERROR_THREAD_ERROR", "error-thread-error" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("GTcpLookupStatus", values);
  }
  return etype;
}

GType
gtcp_connection_status_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { GTCP_CONNECTION_ERROR_CONNECTION_REFUSED, "GTCP_CONNECTION_ERROR_CONNECTION_REFUSED", "error-connection-refused" },
      { GTCP_CONNECTION_ERROR_TIMEOUT, "GTCP_CONNECTION_ERROR_TIMEOUT", "error-timeout" },
      { GTCP_CONNECTION_ERROR_NETWORK_UNREACHABLE, "GTCP_CONNECTION_ERROR_NETWORK_UNREACHABLE", "error-network-unreachable" },
      { GTCP_CONNECTION_ERROR_BAD_BROADCAST_OR_FIREWALL, "GTCP_CONNECTION_ERROR_BAD_BROADCAST_OR_FIREWALL", "error-bad-broadcast-or-firewall" },
      { GTCP_CONNECTION_ERROR_INTERNAL, "GTCP_CONNECTION_ERROR_INTERNAL", "error-internal" },
      { GTCP_CONNECTION_ERROR_THREAD_ERROR, "GTCP_CONNECTION_ERROR_THREAD_ERROR", "error-thread-error" },
      { GTCP_CONNECTION_ERROR_PROXY_ERROR, "GTCP_CONNECTION_ERROR_PROXY_ERROR", "error-proxy-error" },
      { GTCP_CONNECTION_CLOSING, "GTCP_CONNECTION_CLOSING", "closing" },
      { GTCP_CONNECTION_CLOSED, "GTCP_CONNECTION_CLOSED", "closed" },
      { GTCP_CONNECTION_CONNECTED, "GTCP_CONNECTION_CONNECTED", "connected" },
      { GTCP_CONNECTION_CONNECTING, "GTCP_CONNECTION_CONNECTING", "connecting" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("GTcpConnectionStatus", values);
  }
  return etype;
}

GType
gtcp_connection_style_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { GTCP_CONNECTION_HTTP, "GTCP_CONNECTION_HTTP", "http" },
      { GTCP_CONNECTION_FTP, "GTCP_CONNECTION_FTP", "ftp" },
      { GTCP_CONNECTION_OTHER, "GTCP_CONNECTION_OTHER", "other" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("GTcpConnectionStyle", values);
  }
  return etype;
}

GType
gtcp_proxy_type_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { GTCP_PROXY_HTTP, "GTCP_PROXY_HTTP", "http" },
      { GTCP_PROXY_FTP, "GTCP_PROXY_FTP", "ftp" },
      { GTCP_PROXY_OTHER, "GTCP_PROXY_OTHER", "other" },
      { GTCP_PROXY_SSL, "GTCP_PROXY_SSL", "ssl" },
      { GTCP_PROXY_SOCKS4, "GTCP_PROXY_SOCKS4", "socks4" },
      { GTCP_PROXY_SOCKS5, "GTCP_PROXY_SOCKS5", "socks5" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("GTcpProxyType", values);
  }
  return etype;
}

GType
gtcp_send_status_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { GTCP_SEND_DATA_QUEUED, "GTCP_SEND_DATA_QUEUED", "data-queued" },
      { GTCP_SEND_ERROR, "GTCP_SEND_ERROR", "error" },
      { GTCP_SEND_ERROR_NOT_OPEN, "GTCP_SEND_ERROR_NOT_OPEN", "error-not-open" },
      { GTCP_SEND_ERROR_NULL_DATA, "GTCP_SEND_ERROR_NULL_DATA", "error-null-data" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("GTcpSendStatus", values);
  }
  return etype;
}

GType
gtcp_server_kill_style_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { GTCP_SERVER_LEAVE_OPEN, "GTCP_SERVER_LEAVE_OPEN", "leave-open" },
      { GTCP_SERVER_KILL_ON_CLOSE, "GTCP_SERVER_KILL_ON_CLOSE", "kill-on-close" },
      { GTCP_SERVER_KILL_ON_FINALIZE, "GTCP_SERVER_KILL_ON_FINALIZE", "kill-on-finalize" },
      { GTCP_SERVER_FINALIZE_ON_CLOSE, "GTCP_SERVER_FINALIZE_ON_CLOSE", "finalize-on-close" },
      { GTCP_SERVER_FINALIZE_ON_FINALIZE, "GTCP_SERVER_FINALIZE_ON_FINALIZE", "finalize-on-finalize" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("GTcpServerKillStyle", values);
  }
  return etype;
}

GType
gtcp_server_open_status_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { GTCP_SERVER_OPEN_OK, "GTCP_SERVER_OPEN_OK", "ok" },
      { GTCP_SERVER_OPEN_OPENING, "GTCP_SERVER_OPEN_OPENING", "opening" },
      { GTCP_SERVER_OPEN_ERROR_NO_LOCAL_HOSTNAME, "GTCP_SERVER_OPEN_ERROR_NO_LOCAL_HOSTNAME", "error-no-local-hostname" },
      { GTCP_SERVER_OPEN_ERROR_SOCKET_TYPE_PERMS, "GTCP_SERVER_OPEN_ERROR_SOCKET_TYPE_PERMS", "error-socket-type-perms" },
      { GTCP_SERVER_OPEN_ERROR_NO_MEM, "GTCP_SERVER_OPEN_ERROR_NO_MEM", "error-no-mem" },
      { GTCP_SERVER_OPEN_ERROR_TABLE_OVERFLOW, "GTCP_SERVER_OPEN_ERROR_TABLE_OVERFLOW", "error-table-overflow" },
      { GTCP_SERVER_OPEN_ERROR_LOW_PORT_PERMS, "GTCP_SERVER_OPEN_ERROR_LOW_PORT_PERMS", "error-low-port-perms" },
      { GTCP_SERVER_OPEN_ERROR_ALREADY_BOUND, "GTCP_SERVER_OPEN_ERROR_ALREADY_BOUND", "error-already-bound" },
      { GTCP_SERVER_OPEN_ERROR_INTERNAL_ERROR, "GTCP_SERVER_OPEN_ERROR_INTERNAL_ERROR", "error-internal-error" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("GTcpServerOpenStatus", values);
  }
  return etype;
}


/* Generated data ends here */

==> libgtcpsocket-0.2.0.tar.gz: libgtcpsocket-0.2.0/libgtcpsocket/gtcp-socket-type-builtins.c <==

/* Generated data (by glib-mkenums) */

#include <glib-object.h>
#include "gtcp-socket-types.h"


/* enumerations from "./gtcp-socket-types.h" */
GType
gtcp_lookup_status_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { GTCP_LOOKUP_IN_PROGRESS, "GTCP_LOOKUP_IN_PROGRESS", "in-progress" },
      { GTCP_LOOKUP_OK, "GTCP_LOOKUP_OK", "ok" },
      { GTCP_LOOKUP_ERROR_NOT_FOUND, "GTCP_LOOKUP_ERROR_NOT_FOUND", "error-not-found" },
      { GTCP_LOOKUP_ERROR_NO_RECOVERY, "GTCP_LOOKUP_ERROR_NO_RECOVERY", "error-no-recovery" },
      { GTCP_LOOKUP_ERROR_TRY_AGAIN, "GTCP_LOOKUP_ERROR_TRY_AGAIN", "error-try-again" },
      { GTCP_LOOKUP_ERROR_IPV4_IPV6_MISMATCH, "GTCP_LOOKUP_ERROR_IPV4_IPV6_MISMATCH", "error-ipv4-ipv6-mismatch" },
      { GTCP_LOOKUP_ERROR_THREAD_ERROR, "GTCP_LOOKUP_ERROR_THREAD_ERROR", "error-thread-error" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("GTcpLookupStatus", values);
  }
  return etype;
}

GType
gtcp_connection_status_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { GTCP_CONNECTION_ERROR_CONNECTION_REFUSED, "GTCP_CONNECTION_ERROR_CONNECTION_REFUSED", "error-connection-refused" },
      { GTCP_CONNECTION_ERROR_TIMEOUT, "GTCP_CONNECTION_ERROR_TIMEOUT", "error-timeout" },
      { GTCP_CONNECTION_ERROR_NETWORK_UNREACHABLE, "GTCP_CONNECTION_ERROR_NETWORK_UNREACHABLE", "error-network-unreachable" },
      { GTCP_CONNECTION_ERROR_BAD_BROADCAST_OR_FIREWALL, "GTCP_CONNECTION_ERROR_BAD_BROADCAST_OR_FIREWALL", "error-bad-broadcast-or-firewall" },
      { GTCP_CONNECTION_ERROR_INTERNAL, "GTCP_CONNECTION_ERROR_INTERNAL", "error-internal" },
      { GTCP_CONNECTION_ERROR_THREAD_ERROR, "GTCP_CONNECTION_ERROR_THREAD_ERROR", "error-thread-error" },
      { GTCP_CONNECTION_ERROR_PROXY_ERROR, "GTCP_CONNECTION_ERROR_PROXY_ERROR", "error-proxy-error" },
      { GTCP_CONNECTION_CLOSING, "GTCP_CONNECTION_CLOSING", "closing" },
      { GTCP_CONNECTION_CLOSED, "GTCP_CONNECTION_CLOSED", "closed" },
      { GTCP_CONNECTION_CONNECTED, "GTCP_CONNECTION_CONNECTED", "connected" },
      { GTCP_CONNECTION_CONNECTING, "GTCP_CONNECTION_CONNECTING", "connecting" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("GTcpConnectionStatus", values);
  }
  return etype;
}

GType
gtcp_connection_style_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { GTCP_CONNECTION_HTTP, "GTCP_CONNECTION_HTTP", "http" },
      { GTCP_CONNECTION_FTP, "GTCP_CONNECTION_FTP", "ftp" },
      { GTCP_CONNECTION_OTHER, "GTCP_CONNECTION_OTHER", "other" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("GTcpConnectionStyle", values);
  }
  return etype;
}

GType
gtcp_proxy_type_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { GTCP_PROXY_HTTP, "GTCP_PROXY_HTTP", "http" },
      { GTCP_PROXY_FTP, "GTCP_PROXY_FTP", "ftp" },
      { GTCP_PROXY_OTHER, "GTCP_PROXY_OTHER", "other" },
      { GTCP_PROXY_SSL, "GTCP_PROXY_SSL", "ssl" },
      { GTCP_PROXY_SOCKS4, "GTCP_PROXY_SOCKS4", "socks4" },
      { GTCP_PROXY_SOCKS5, "GTCP_PROXY_SOCKS5", "socks5" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("GTcpProxyType", values);
  }
  return etype;
}

GType
gtcp_send_status_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { GTCP_SEND_DATA_QUEUED, "GTCP_SEND_DATA_QUEUED", "data-queued" },
      { GTCP_SEND_ERROR, "GTCP_SEND_ERROR", "error" },
      { GTCP_SEND_ERROR_NOT_OPEN, "GTCP_SEND_ERROR_NOT_OPEN", "error-not-open" },
      { GTCP_SEND_ERROR_NULL_DATA, "GTCP_SEND_ERROR_NULL_DATA", "error-null-data" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("GTcpSendStatus", values);
  }
  return etype;
}

GType
gtcp_server_kill_style_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { GTCP_SERVER_LEAVE_OPEN, "GTCP_SERVER_LEAVE_OPEN", "leave-open" },
      { GTCP_SERVER_KILL_ON_CLOSE, "GTCP_SERVER_KILL_ON_CLOSE", "kill-on-close" },
      { GTCP_SERVER_KILL_ON_FINALIZE, "GTCP_SERVER_KILL_ON_FINALIZE", "kill-on-finalize" },
      { GTCP_SERVER_FINALIZE_ON_CLOSE, "GTCP_SERVER_FINALIZE_ON_CLOSE", "finalize-on-close" },
      { GTCP_SERVER_FINALIZE_ON_FINALIZE, "GTCP_SERVER_FINALIZE_ON_FINALIZE", "finalize-on-finalize" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("GTcpServerKillStyle", values);
  }
  return etype;
}

GType
gtcp_server_open_status_get_type (void)
{
  static GType etype = 0;
  if (etype == 0) {
    static const GEnumValue values[] = {
      { GTCP_SERVER_OPEN_OK, "GTCP_SERVER_OPEN_OK", "ok" },
      { GTCP_SERVER_OPEN_OPENING, "GTCP_SERVER_OPEN_OPENING", "opening" },
      { GTCP_SERVER_OPEN_ERROR_NO_LOCAL_HOSTNAME, "GTCP_SERVER_OPEN_ERROR_NO_LOCAL_HOSTNAME", "error-no-local-hostname" },
      { GTCP_SERVER_OPEN_ERROR_SOCKET_TYPE_PERMS, "GTCP_SERVER_OPEN_ERROR_SOCKET_TYPE_PERMS", "error-socket-type-perms" },
      { GTCP_SERVER_OPEN_ERROR_NO_MEM, "GTCP_SERVER_OPEN_ERROR_NO_MEM", "error-no-mem" },
      { GTCP_SERVER_OPEN_ERROR_TABLE_OVERFLOW, "GTCP_SERVER_OPEN_ERROR_TABLE_OVERFLOW", "error-table-overflow" },
      { GTCP_SERVER_OPEN_ERROR_LOW_PORT_PERMS, "GTCP_SERVER_OPEN_ERROR_LOW_PORT_PERMS", "error-low-port-perms" },
      { GTCP_SERVER_OPEN_ERROR_ALREADY_BOUND, "GTCP_SERVER_OPEN_ERROR_ALREADY_BOUND", "error-already-bound" },
      { GTCP_SERVER_OPEN_ERROR_INTERNAL_ERROR, "GTCP_SERVER_OPEN_ERROR_INTERNAL_ERROR", "error-internal-error" },
      { 0, NULL, NULL }
    };
    etype = g_enum_register_static ("GTcpServerOpenStatus", values);
  }
  return etype;
}


/* Generated data ends here */
